**Table of Contents**

- [Plover](#plover)
  - [What is stenography?](#what-is-stenography)
  - [How fast can stenographers write?](#how-fast-can-stenographers-write)
  - [What is Plover?](#what-is-plover)
  - [Why "Plover"?](#why-plover)
  - [Who's responsible for Plover's development?](#whos-responsible-for-plovers-development)
  - [Why does Plover exist?](#why-does-plover-exist)
  - [How does Stenography compare to typing?](#how-does-stenography-compare-to-typing)
  - [What does using Plover look like?](#what-does-using-plover-look-like)
  - [How does it compare to alternative layouts like Dvorak and Colemak?](#how-does-it-compare-to-alternative-layouts-like-dvorak-and-colemak)
  - [If I learn steno, will it make using QWERTY harder?](#if-i-learn-steno-will-it-make-using-qwerty-harder)
  - [Why isn't steno more popular than QWERTY?](#why-isnt-steno-more-popular-than-qwerty)
  - [Will stenography be replaced with automatic voice recognition?](#will-stenography-be-replaced-with-automatic-voice-recognition)
  - [What theory is Plover's default dictionary based on?](#what-theory-is-plovers-default-dictionary-based-on)
  - [Where can I find other people who use Plover?](#where-can-i-find-other-people-who-use-plover)
  - [How can I help?](#how-can-i-help)
- [Using Plover](#using-plover)
  - [How can I get started?](#how-can-i-get-started)
  - [What hardware do I need?](#what-hardware-do-i-need)
  - [Can I still get by without a professional machine?](#can-i-still-get-by-without-a-professional-machine)
  - [Can I use Plover for normal computer use?](#can-i-use-plover-for-normal-computer-use)
  - [Can I use Plover for programming?](#can-i-use-plover-for-programming)
  - [Can I use Plover for languages other than English?](#can-i-use-plover-for-languages-other-than-english)
  - [How long does it take to learn?](#how-long-does-it-take-to-learn)
  - [What's a brief/stroke/arpeggiating/etc.?](#whats-a-briefstrokearpeggiatingetc)
  - [What can't Plover do?](#what-cant-plover-do)
- [Comparisons to professional stenography](#comparisons-to-professional-stenography)
  - [Why does steno need amateurs?](#why-does-steno-need-amateurs)
  - [What is Steno Arcade?](#what-is-steno-arcade)
    - [Is Steno Arcade going to put steno schools out of business?](#is-steno-arcade-going-to-put-steno-schools-out-of-business)
  - [How is Plover different from commercial steno programs?](#how-is-plover-different-from-commercial-steno-programs)
  - [Is Plover going to put CAT software companies out of business?](#is-plover-going-to-put-cat-software-companies-out-of-business)
  - [What are some features in Plover not commonly found in most CAT software?](#what-are-some-features-in-plover-not-commonly-found-in-most-cat-software)
  - [Can I use my Luminex/Stentura/Lightspeed/other stenotype machine?](#can-i-use-my-luminexstenturalightspeedother-stenotype-machine)
  - [Can I use my dictionaries from another program?](#can-i-use-my-dictionaries-from-another-program)

## Plover

### What is stenography?

*Stan's Quick and Dirty: How Stenography Works*<br>
[![Plover Dictionary Update Demo](https://img.youtube.com/vi/62l64Acfidc/0.jpg)](https://youtu.be/62l64Acfidc "Plover Dictionary Update Demo")<br>
[(click to view video — 3:13)](https://youtu.be/62l64Acfidc "Plover Dictionary Update Demo")

[Stenography](https://en.wikipedia.org/wiki/Shorthand) is a form of shorthand writing/typing, usually done on a [special machine](https://en.wikipedia.org/wiki/Stenotype) (although with Plover, you can use computer keyboard that has [n-key rollover](https://en.wikipedia.org/wiki/Rollover_(key))). It was invented in the early 1900s.

Real-time machine stenography is a code translation system that lets users enter words and syllables by pressing multiple keys simultaneously in a chord, which is then instantly translated into English text.

### How fast can stenographers write?

| Method | Typical Speed |
| ----------|-----------|
| Handwriting | 30 WPM |
| Average Typist | [40 WPM](https://www.youtube.com/watch?v=P5Ml_y5-KmI&list=PLFCCB3E328121B261) |
| Fast Typist | [120 WPM](https://www.youtube.com/watch?v=k71XmfDM1dU) |
| Typing World Record | [200 WPM](https://www.youtube.com/watch?v=FgjivmUE9o8) |
| Voice Writer | 180 WPM |
| Average Speech | 200 WPM |
| Amateur Stenographer | [160 WPM](https://www.youtube.com/watch?v=a9hVQ5BT1ls) |
| Professional Stenographer | [225 WPM](https://www.youtube.com/watch?v=UNmqwUEEJA4) |
| [Steno World Record](https://www.guinnessworldrecords.com/world-records/fastest-realtime-court-reporter-(stenotype-writing)) | 360 WPM |

In the first year of steno school, many students learn to exceed 100 words per minute. By comparison, top qwerty typists can do 120 WPM, top Dvorak typists around 140 WPM, and voice writers dictating to voice recognition software around 180 WPM. But experienced stenographers can enter text at up to 300 words per minute (the world record is actually 360, but that's an outlier). Conceivably, with practice, amateur steno users could reach 160-200 words per minute.

(also see [How long does it take to learn?](#how-long-does-it-take-to-learn))

### What is Plover?

Plover is a 100% free, open source steno program that lets you use your keyboard as a steno machine.It is a small Python application that you run in the background. It acts as a translator to read steno movements and then emulate keystrokes, so the programs you use can't tell that you are using steno.

Plover is available on Windows, Mac and Linux. To get started, follow the [Beginner's Guide](https://github.com/openstenoproject/plover/wiki/Beginner's-Guide:-Get-Started-with-Plover).

### Why "Plover"?

The short answer is that it's a two-syllable, six-letter word that can be written in a single stroke on a steno machine. The longer answer is [here](http://plover.stenoknight.com/2010/03/why-plover.html).

### Who's responsible for Plover's development?

Plover was originally created by [Mirabai Knight](http://www.blogger.com/profile/16494847224950297255) and [Joshua
Harlan Lifton](http://launchpad.net/~joshua-harlan-lifton), and is the software arm of [The Open Steno Project](http://openstenoproject.org/), an umbrella organization for open source steno tools. The current lead developer is Theodore (Ted) Morin.

### Why does Plover exist?

Falling numbers of graduates from steno schools and the high attrition of retiring stenographers initially caused [Mirabai Knight](http://StenoKnight.com) to worry about the future of her profession, as inferior non-verbatim systems (e.g. ER,
Typewell, C-Print, automated speech recognition) threaten to fill in the supply vacuum caused by a shortage of steno professionals.

At the same time, she saw steno's great potential in helping to improve the lives of the large number of people who work in front of computers all day, whether they're writing prose, creating software, entering data, or communicating in text with friends and coworkers.  As a method of text entry, Qwerty is inefficient and unergonomic, but so far it hasn't been supplanted by any of the competing systems (such as [Dvorak](http://en.wikipedia.org/wiki/Dvorak_Simplified_Keyboard) or [Colemak](http://en.wikipedia.org/wiki/Keyboard_layout#Colemak)), because they're simply not powerful enough to justify the time investment necessary to learn them. Steno, on the other hand, is.

So Plover has a double-pronged approach:

1. Find people who want to learn steno, whether just as amateurs or as aspiring professionals, and give them a cheap, simple, and fun way to try it out.
1. Then, for those few who find that they've got both a gift and a passion for steno, provide an opportunity to turn that skill into a career, feeding the talent pools for future professional stenographers and ensuring that steno as a profession will survive into the future.

### How does Stenography compare to typing?

- Typing is (usually) data entry with single fingers

Most likely, you are using a qwerty or dvorak keyboard layout to type everything out character by character. If you ever practiced piano, it might be helpful to liken them to certain piano pieces common in a pianist's repertoire. The "typewriter-style" systems (qwerty, dvorak, etc.) are like [Chopin's Fantasie Impromptu](https://www.youtube.com/watch?v=tvm2ZsRv3C8).

Notice how this piece — like typing — is mainly runs of single fingers. When you learn and practice this piece, you often do many finger exercises to strengthen certain fingers to increase your speed.

- Stenography is chorded data entry, using multiple fingers

However, Plover, and other steno systems, use keyboard "chords" to type syllables, words, or entire phrases. You press keys, and lift off, rather than pressing down individual keys one after the other.

> "When your fingers are in position, press them all down together, and release them. Out comes the word 'tap'! You've just tapped your first word in steno! Notice that it doesn't really matter that all the keys go down absolutely simultaneously. The only thing Plover cares about is that there's one moment in time when all three keys are down together."
>
> — [Learn Plover!](https://sites.google.com/site/learnplover/lesson-1-fingers-and-keys)

Plover — and all steno systems — express words primarily as groups of sounds rather than groups of letters of the alphabet.

"Steno-style" systems (NYCI, StenoEd, Phoenix, etc.) are like [Rachmaninoff's Prelude in G Minor](https://www.youtube.com/watch?v=4QB7ugJnHgs).

Unlike the Chopin, this piece is almost entirely chorded. When learning a piece like this, you learn how to block your chords. So your approach to learning steno may be completely different than learning a different keyboard layout, since it's a completely different system.

### What does using Plover look like?

| **QWERTY versus Stenography on Steno Arcade** | **Plover wins the race!** | **Demonstration of Plover with Qwerty Keyboard** |
| - | - | - |
| [![QWERTY versus Stenography on Steno Arcade](https://i.ytimg.com/vi/UtQzTUEuPWo/hqdefault.jpg)](https://youtu.be/UtQzTUEuPWo?t=8s)<br>[(click to view video — 3:25)](https://youtu.be/UtQzTUEuPWo?t=8s) | [![Plover Wins the Race!](https://img.youtube.com/vi/jkUyg_uoidY/0.jpg)](https://www.youtube.com/watch?v=jkUyg_uoidY)<br>[(click to view video — 0:30)](https://www.youtube.com/watch?v=jkUyg_uoidY) | [![Demonstration of Plover with Qwerty Keyboard](https://img.youtube.com/vi/JXQQzW99cAI/0.jpg)](https://www.youtube.com/watch?v=JXQQzW99cAI)<br>[(click to view video — 1:05)](https://www.youtube.com/watch?v=JXQQzW99cAI) |
| **Realtime Text to Speech with Plover** | **Coding in Stenography, Quick Demo** | **Rails 7: The Steno Demo** |
| [![Realtime Text to Speech with Plover](https://img.youtube.com/vi/K3MYFT6VZk8/0.jpg)](https://www.youtube.com/watch?v=K3MYFT6VZk8)<br>[(click to view video — 3:36)](https://www.youtube.com/watch?v=K3MYFT6VZk8) | [![Coding in Stenography, Quick Demo](https://i.ytimg.com/vi/RBBiri3CD6w/hqdefault.jpg)](https://www.youtube.com/watch?v=RBBiri3CD6w)<br>[(click to view video — 2:00)](https://www.youtube.com/watch?v=RBBiri3CD6w)| [![Rails 7: The Steno Demo](https://i.ytimg.com/vi/q7g0ml60LGY/hqdefault.jpg)](https://www.youtube.com/watch?v=q7g0ml60LGY)<br>[(click to view video — 2:08:59)](https://www.youtube.com/watch?v=q7g0ml60LGY)|

### How does it compare to alternative layouts like Dvorak and Colemak?

In terms of speed, professional stenographers are expected to get to 225wpm at minimum, and the [world record is 360wpm](https://www.guinnessworldrecords.com/world-records/fastest-realtime-court-reporter-(stenotype-writing)). Audiobooks are narrated at around 150wpm ([source from an Audible/iTunes book provider](https://help.acx.com/s/article/how-long-will-my-narrated-audiobook-be)). The world record typist, Barbara Blackburn, has achieved a peak speed of 212wpm on Dvorak.

In terms of comfort, many people say than stenography is more comfortable. Here is [ Mirabai's article on the ergonomic argument for stenography](http://plover.stenoknight.com/2010/05/ergonomic-argument.html). There are fewer keys and therefore less finger movement. You write chords, not letters, so that reduces vertical movement. And you don't write out every single character — spaces are automatically inserted, and you can write whole words and phrases with a single stroke.

### If I learn steno, will it make using QWERTY harder?

If you have used alternative layouts like Dvorak and Colemak, you might have found that learning one would make it harder to use QWERTY (e.g. needing time to warm up when changing layouts, losing speed).

From reports of users in the [Plover discord](https://github.com/openstenoproject/plover/wiki/Links-to-the-Steno-Community), people don't seem to experience this with steno and QWERTY in the same way. This could be because:

- Chorded input is very different from typing, so the muscle memory doesn't interfere as much
- Steno is typically used on hardware that feels very different (e.g. non-staggered, light keys)

### Why isn't steno more popular than QWERTY?

There are a number of possible reasons:

1. Stenography was copyrighted for many decades, which limited the amount of competition in the marketplace.
1. The vendors decided to focus on high value products in market sectors where organizations would be willing to pay higher prices. Professional hardware and software can cost several thousands of dollars.
1. It takes longer to learn how to write with steno than it does learning how to type. (See [How long does it take to learn?](#how-long-does-it-take-to-learn))
1. Plover software, and [suitable low cost hardware](https://github.com/openstenoproject/plover/wiki/Supported-Hardware), didn't exist [until recently](https://github.com/openstenoproject/plover/wiki/Open-Steno-Project-Timeline).
### Will stenography be replaced with automatic voice recognition?

Mirabai Knight has done [a presentation](https://www.youtube.com/watch?v=XKe1O7ppyqQ) on this topic. As a summary, automatic voice recognition is still not accurate enough in certain situations such as if there is bad audio, someone speaking with a non-standard accent, or if the cost of certain mistakes is too high.

Some people are experimenting with voice typing technology, where someone who knows the voice recognition software well speaks into a special mic.

### What theory is Plover's default dictionary based on?

It's basically Mirabai Knight's personal dictionary, which is a mix of New York Career Institute theory and Sten Ed, with several thousand tweaks, briefs, and additions of her own.

### Where can I find other people who use Plover?

Check out these [links to the community](https://github.com/openstenoproject/plover/wiki/Links-to-the-Steno-Community).

### How can I help?

The Open Steno Project is run by volunteers.

You can help by:

- [Contributing code](https://github.com/openstenoproject/plover/blob/master/CONTRIBUTING.md#contributing-code)
- [Reporting issues](https://github.com/openstenoproject/plover/blob/master/CONTRIBUTING.md#reporting-issues)
- [Editing this wiki](https://github.com/openstenoproject/plover/wiki)
- [Getting involved in the community](https://github.com/openstenoproject/plover/wiki/Links-to-the-Steno-Community)
- [Donating money](https://www.openstenoproject.org/donate/)
- Telling people about Open Steno, Plover, and stenography!

## Using Plover
### How can I get started?

The [Beginner's Guide](https://github.com/openstenoproject/plover/wiki/Beginner's-Guide:-Get-Started-with-Plover) has everything you need to get started, including how to install Plover, what hardware you need, and how to practice and learn.

### What hardware do I need?

You can just get started and try Plover out on the keyboard you are using right now.

However, some keyboards will be easier to use for stenography than others. Features to look out for are:
 - [NKRO](https://github.com/openstenoproject/plover/wiki/Supported-Hardware#whats-nkro), so you don't have to [arpeggiate](https://github.com/openstenoproject/plover/wiki/Glossary#arpeggiate).
 - No stagger and a smaller gap between keys, so that you can easily press keys that are next to each other. However, it's possible to [adapt a keyboard](https://github.com/openstenoproject/plover/wiki/Supported-Hardware#adapt-a-keyboard-for-steno-use) to work better for steno.
 - Lighter keys, so it's less fatiguing.

[Find more information in this section of the beginner's guide](https://github.com/openstenoproject/plover/wiki/Beginner's-Guide:-Get-Started-with-Plover#connect-a-compatible-keyboard-or-stenography-machine), or in the [keyboards section of the hardware page](https://github.com/openstenoproject/plover/wiki/Supported-Hardware#keyboards).

### Can I still get by without a professional machine?

Yes, Mirabai Knight wrote in [her review of the Georgi](http://plover.stenoknight.com/2019/12/georgi-review.html) that she was able to caption 8 hour conferences with no fatigue. General consensus is that this should also be possible with other [hobbyist steno machines](https://github.com/openstenoproject/plover/wiki/Supported-Hardware#commercially-available-hobbyist-machines).

This isn't to say that professional machines do not have some benefits:
- They do not require a computer, instead they can store text on the machine
- The pressure and sensitivity can be adjusted on the fly and per key
- The amount of force you need to use is similar regardless of the number of keys you press. With keyboards, where each key is separate, a stroke that uses 8 keys will require 8 times the amount of force as a single key

[Thomas Baart's post "Exploring Professional Stenotype Machines"](https://thomasbaart.nl/2019/01/24/exploring-professional-stenotype-machines/) goes into more of the features that professional machines have.

### Can I use Plover for normal computer use?

Yes! Plover can send nearly every keyboard key or combination you like. See the [dictionary format](https://github.com/openstenoproject/plover/wiki/Dictionary-Format#keyboard-shortcuts) for more information.

The only limitation is that it cannot hold down keys (for example, if you want to shift+drag). There is currently a [pull request](https://github.com/openstenoproject/plover/pull/1278) for this, so hopefully it will be possible soon.

Since there are many symbols and modifiers and not all of these are defined in the default Plover dictionaries, you may be interested in some dictionaries and plugins other people have made:

 - [Emily Symbols](https://github.com/EPLHREU/emily-symbols), for typing symbols (including those not in the main Plover dictionary)
 - [Emily Modifiers](https://github.com/EPLHREU/emily-modifiers), for typing with modifiers (e.g. ALT+D, CTRL+-, SUPER, SHIFT+F5)
 - [Abby's Left Hand Modifiers](https://github.com/4hrue2kd83f/abby-left-hand-modifiers), for typing with modifiers but keeping the right hand free
 - [Plover Emoji](https://github.com/morinted/plover_emoji), for typing emoji

### Can I use Plover for programming?

Yes, and many people do!

For example:
- The author of [Art of Chording](https://www.artofchording.com/) (a Plover theory textbook) is a programmer and he has some videos of him programming with steno: [Coding in Stenography, Quick Demo](https://www.youtube.com/watch?v=RBBiri3CD6w), [Raw unedited steno coding demo](https://www.youtube.com/watch?v=711T2simRyI)
- [Paul Fioravanti](https://www.paulfioravanti.com/) recreated DHH's rails 7 demo using steno: [Rails 7: The Steno Demo](https://www.youtube.com/watch?v=q7g0ml60LGY)
- Mirabai Knight, who started Plover, has a [demo of her transcribing some of Plover's python source code](https://www.youtube.com/watch?v=jRFKZGWrmrM)

To make programming easier with steno:
- For writing words/symbols used in programming, you can define a dictionary for them. You may want to use a dictionary someone else has already made, or look there for inspiration:
  - Specific dictionaries
    - [Emily Symbols](https://github.com/EPLHREU/emily-symbols) for writing symbols.
  - Dictionary collections which include some programming related dictionaries
    - [stenodict](https://www.openstenoproject.org/stenodict/) a user-submitted collection of dictionaries
    - [Di's steno dictionaries](https://github.com/didoesdigital/steno-dictionaries), the creator of Typey Type (and whose programming dictionaries can be [practiced on the site](https://didoesdigital.com/typey-type/lessons#tech))
    - [Emily's dictionaries](https://github.com/EPLHREU/emily-dictionaries)
    - [Antistic's dictionaries](https://github.com/antistic/steno-dictionaries)
    - [Paul's dictionaries](https://github.com/paulfioravanti/steno-dictionaries)
    - [Josiah's dictionaries](https://github.com/Josiah-tan/plover_dict)

- For writing in snake/camel/pascal/etc. case: You can set [typing modes](https://github.com/openstenoproject/plover/wiki/Dictionary-Format#modes), [control capitalisation](https://github.com/openstenoproject/plover/wiki/Dictionary-Format#capitalizing), or type symbols like `_`. There are also various plugins (see a list [here](https://github.com/openstenoproject/plover/discussions/1355)) which lets you do this retroactively.
- Since it's harder to use both the mouse and steno at the same time, you may also want to learn how to use more keyboard shortcuts. Check out the question ["Can I use Plover for normal computer use?"](#can-i-use-plover-for-normal-computer-use) above.

### Can I use Plover for languages other than English?

Plover supports custom systems, so it's possible to use different language systems in Plover. Here's a list of current [chorded systems](https://github.com/openstenoproject/plover/wiki/Steno-Layouts-&-Supported-Languages) that have been made.

If you want to fingerspell with non-English letters, JorWat has a [fingerspelling dictionary for diacritics](https://github.com/JorWat25/dictionaries/blob/main/diacritics.json) (e.g. é, ç, ø, ñ etc.).

Unfortunately, due to the lack of learning resources for other languages, it is usually advised that you learn the English system first so that you get a good understanding of stenography before learning another system.

The #multilingual channel on the [discord server](https://discord.gg/0lQde43a6dGmAMp2) is likely the best place to seek support for other languages.

### How long does it take to learn?

You can see the [2021 community survey results](https://docs.google.com/forms/d/1lPX-DkdqNm0L0JfgjjxwQqvYxwSMtB8HmiMCcIhAcS0/viewanalytics) to see how long people have been learning stenography, and what their speed is. It is reasonable to get to around your qwerty speed in about 6 months, though of course it depends on your qwerty speed and how you practice.

Aerick made a [youtube video showing his progress over 5 months](https://www.youtube.com/watch?v=28v3cm21uAA), where he was able to get to 100-160wpm, depending on the text.

People in professional stenography schools often expect to take about 2 years to get to 225wpm with 98% accuracy. However, stenography school is not a necessarily a one-to-one comparison to your personal use case, since it is designed as a track to being a professional court reporter/live captioner/CART provider etc. This may involve learning specific legal terminology, medical terminology, CAT software training, how courts work etc.

### What's a brief/stroke/arpeggiating/etc.?

You can find a list of commonly used terms in the [glossary](https://github.com/openstenoproject/plover/wiki/Glossary).

### What can't Plover do?

For general information on what Plover cannot do, see the [open feature requests](https://github.com/openstenoproject/plover/issues?q=is%3Aissue+is%3Aopen+label%3Afeature-request). If there's something you'd like Plover to do that it currently doesn't, you can open a feature request of your own.

- Sticky Metakeys (issue [#72](https://github.com/openstenoproject/plover/issues/72))

Plover lacks arbitrarily stackable metakeys. You can explicitly define a metakey+key combination in the dictionary (and there is a dictionary for general shortcuts such as `Control-C`), but you can't map a stroke to, say, `Control` and then be able to simulate holding it down while choosing another key in realtime to be activated along with it.

- Transcript management and workflow

Plover is not court reporting (CAT) software, and there are no plans to make it into CAT replacement software. It has no transcript preparation utilities of any kind. For example: document approval and delivery workflow, document encryption, or file management. See [Is Plover going to put CAT software companies out of business?](#is-plover-going-to-put-cat-software-companies-out-of-business).


## Comparisons to professional stenography
### Why does steno need amateurs?

In most skill-based fields — music, photography, athletics, and computer programming, to name a few — a healthy pool of amateurs makes it possible for professionals to exist. People cultivate an interest, buy some cheap equipment, take a few classes, discover that they love the work, hone their skills with thousands of hours of practice, and eventually a very dedicated and talented few are able to become good enough to make a living at what they love. The rest do it without compensation, just for their own pleasure and enjoyment. This is the natural ecosystem of any difficult skill: A wide base of dabblers and dilettantes at the bottom, and a small number of world class hotshots at the top.

Without a steady supply of amateurs to hold the ranks, it's difficult for professionals to exist. Many legendary musicians started out with a $50 guitar and a tattered songbook. If every guitar cost $5,000 and the only way to learn how to play it was at a conservatory, how many potentially great guitarists would never even get within strumming range? Plover reduces the $1,500+ initial startup cost of steno to around $70, which means vastly more people can give it a try and see if it might be for them.

### What is Steno Arcade?

[![Steno Arcade](http://cdn.akamai.steamstatic.com/steam/apps/256661129/movie.293x165.jpg?t=1456810705)](http://store.steampowered.com/app/449000/)

[Steno Arcade](http://store.steampowered.com/app/449000/) is a suite of arcade games designed to teach and drill steno fundamentals in an immersive, addictive, responsive, and interactive way.

#### Is Steno Arcade going to put steno schools out of business?

Very unlikely. There will always be a place for high-speed dictation and one-on-one interaction between steno professionals and students. Steno Arcade will be directed at people who want to use steno non-professionally, aren't sure whether steno is for them, or who want to try it out a bit before committing to making it a definite career goal.

There will always be some autodidacts who can get through the Steno Arcade program entirely by themselves and find themselves certification-ready at the end of it, but that will probably be fairly rare.

### How is Plover different from commercial steno programs?

Well, first off, it's free. Free to distribute, free to modify. No dongles, no upgrade fees, no constraints. That's already a $4,000 difference.

To the developer's knowledge, it's also the only steno software that works on a buffer-based system rather than a timer-based system, and that has direct access to the OS rather than filtering everything into a steno-specific word processor. This means it's lightweight, powerful, and doesn't require a 1.5-second wait time between when a stroke is entered and when the translation appears in an external program. In Plover, the translation appears instantly, and the software isn't cluttered up with file managers, printer handlers, and other court-reporting flimflam that an amateur stenographer will never use. Instead, it's a direct conduit between the steno keyboard and the OS. Plover can do everything a qwerty keyboard can do – but much, much faster.

### Is Plover going to put CAT software companies out of business?

Definitely not. Plover is not court reporting software. It has no transcript preparation utilities of any kind. However, it might prove useful to people who use other CAT systems for their work but would like to use Plover as a replacement for their qwerty keyboard in daily computing tasks. At some point Plover might become a solid option for CART providers, but there are no plans to make it into CAT replacement software for either court reporters or broadcast captioners.

### What are some features in Plover not commonly found in most CAT software?

1. Plover's main purpose is to replace the qwerty keyboard with a steno keyboard. Unlike other CAT systems, it does not have a text entry window; it's a pure conduit straight to the operating system. Anything you can do with a qwerty keyboard can be done with Plover, and you can use it with the word processor or text editor of your choice.
1. Plover runs on Windows, Mac, and Linux.
1. Its length-based buffer, as opposed to the time-based buffer used in most CAT software, ensures instant
delivery of text with no buffer flushing or time delay.
1. Its dictionary is text-based, so you can search through and edit it using any text editor. Updating the dictionary from the writer is smooth and seamless.
1. And, of course, its biggest feature: It's 100% free and open source. You can download it, keep it on a USB key, and have it to hand as a backup in case something happens to your CAT software. You can distribute it to interested friends and potential steno students. You can run it on as many computers as you like, with absolutely no restrictions. And, if you
know how to program in Python, you can modify it and change it to your heart's delight.

Plover Dictionary Update Demo<br>
[![Plover Dictionary Update Demo](https://img.youtube.com/vi/eSU5JlVXT1A/0.jpg)](https://youtu.be/eSU5JlVXT1A "Plover Dictionary Update Demo")<br>
[(click to view video — 1:44)](https://youtu.be/eSU5JlVXT1A)
### Can I use my Luminex/Stentura/Lightspeed/other stenotype machine?

Yes! See the [stenotype machine section in supported hardware](https://github.com/openstenoproject/plover/wiki/Supported-Hardware#stenotype-machines) for machines that have been confirmed to work with Plover, and any specific setup instructions you may need to follow.

### Can I use my dictionaries from another program?

Yes, Plover supports the RTF/CRE format, which is exportable from just about any CAT software.
