A chorded system, or *system* for short, is a set of rules for Plover that determines the keys, language rules, and default dictionaries in Plover. **System Plugins** allow Plover to support different machine types and languages other than English.

The [American Ward-Ireland Stone Stenotype](https://en.wikipedia.org/wiki/Stenotype) is the default layout in Plover, and what we teach and recommend by default. However, there are many different chorded systems worldwide and some of them have been implemented in Plover.

Note that not all of these systems have been fully implemented; many of them are probably not going to be implemented in Plover, but they have been listed so that you may use them as a reference should you choose to create your own layout/system.

If you can't find your language in the main language list, you might take a look at the [Multilingual Systems](#multilingual-systems) section. These systems support multiple languages and are often orthographic (i.e. they are based on spelling rather than pronunciation).

For systems proposed for implementation, check out the [issues list](https://github.com/openstenoproject/plover/issues?q=is%3Aopen+label%3Aplugin-candidate+label%3Asystems).

## Contents

- [English](#english)
- [English - Shavian / 𐑖𐑱𐑝𐑾𐑯](#english-shavian)
- [Chinese - Cantonese / 粵語](#chinese-cantonese)
- [Chinese - Mandarin / 國語 / 普通话](#chinese-mandarin)
- [Czech / Čeština](#czech)
- [Danish / Dansk](#danish)
- [Dutch / Nederlands](#dutch)
- [Finnish / Suomi](#finnish)
- [French / Français](#french)
- [German / Deutsch](#german)
- [Greek / Ελληνικά](#greek)
- [Hebrew / עברית](#hebrew)
- [Italian / Italiano](#italian)
- [Japanese / 日本語](#japanese)
- [Korean / 한국어](#korean)
- [Portuguese / Português](#portuguese)
- [Russian / Русский](#russian)
- [Spanish / Español](#spanish)
- [Swedish / Svenska](#swedish)
- [Thai / ภาษาไทย](#thai)
- [Turkish / Türkçe](#turkish)
- [Vietnamese / Tiếng Việt](#vietnamese)
- [Multilingual Systems](#multilingual-systems)

---

## English

### English Stenotype

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/en-0.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Ward Stone Ireland</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>Fully Implemented (Bundled with Plover)</td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>
        Full Dictionary: 140,000+ Entries <br>
        (Alternate Theories Available)
    </td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>See the <a href="https://github.com/openstenoproject/plover/wiki/Learning-Stenography">Learning Resources</a> page.</td>
  </tr>
</table>

The default system in Plover. Used internationally for English-language transcription, invented in the United States in 1913.

<br>

### Jackdaw

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/en-jack.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Orthographic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td><a href="https://github.com/user202729/plover-jackdaw-alt1">Plover Jackdaw</a> by user202729</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://sites.google.com/site/learnplover/jackdaw">Learn Plover Jackdaw Tutorial</a>
    </td>
  </tr>
</table>

An orthographic system based entirely on spelling rather than phonetics, allowing the user to type any word as long as they know the spelling.

<br>

### Kinglet

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/en-king.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Zachary Brown</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Orthographic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete for an older version of Plover</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://drive.google.com/file/d/0B9Je8TDYCh1xSVRjVmQ0RUF0ejA/edit?resourcekey=0-6XylRvd298I4w4OVUc-IDg">Plover 2.5.8 Modified for Kinglet</a> by Benoit Pierre
    </td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://sites.google.com/site/learnplover/kinglet-a-letter-based-stenotype-system">Learn Plover Kinglet Tutorial</a>
    </td>
  </tr>
</table>

Kinglet was an attempt to create a spelling-based steno system that would have a theoretical speed equal to Plover (about 1 word per stroke). It succeeds in doing this at the cost of a high degree of finger contortion and accuracy in each individual finger, making it difficult to use.

<br>

### Michela for English

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/en-mich.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Dictionary under construction</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/benoit-pierre/plover_michela">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Sample: 150 Entries</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        Manual and sample dictionary <a href="https://github.com/Sillabix/Sistema-fonetico-Michela.-Michela-phonetic-system">here</a>.
    </td>
  </tr>
</table>

An experimental system based on the Italian Michela system, widely used in Italy. The system uses a piano-style keyboard; it was created for the purpose of extending the application of the Michela keyboard to the English language, drawn from the "Method for the English language" included in the machine's 1878 American patent.

<br>

### Midi4Text for English

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/en-midi.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Orthographic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/nsmarkop/plover_midi4text">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        Manual and sample dictionary <a href="https://www.midi4text.com/">Midi4Text Website</a>.
    </td>
  </tr>
</table>

An English orthographic system that uses a piano-style keyboard based on the Michela system. Unlike the phonetic Michela for English system, this system is based on spelling and does not require a dictionary.

<br>

### Phenrsteno

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/en-phen.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Gregory Chamberlain</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/chambln/plover-phenrsteno">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Basic: 15,000+ Entries</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://github.com/chambln/plover-phenrsteno/wiki">Phenrsteno Wiki</a>
    </td>
  </tr>
</table>

Phenrsteno is a machine shorthand theory implemented as a system for Plover. It's designed for non-rhotic accents—British English in particular—but really anyone might like to use it or adapt it to their own idiolect.

<br>

### Possum Palantype

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/en-pala.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/morinted/plover_palantype">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Basic: 21,000+ Entries</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="http://www.openstenoproject.org/palantype/">Learn Palantype! Page</a>
    </td>
  </tr>
</table>

The [Possum Palantype](http://www.openstenoproject.org/palantype) is a system invented in the UK which was optimized to have readable shorthand notes (the untranslated output). It has more keys than the Ireland layout. It is still used by some [STTRs](https://en.wikipedia.org/wiki/Speech-to-text_reporter) worldwide for writing in English.

---

## English (Shavian)

### Shavian Stenotype

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/en-shav.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Lynn (Ruma)</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Orthographic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Work in Progress</td>
  </tr>
</table>

Shavian is an alternate alphabet for English; the Shavian Stenotype is a steno system designed to be used on a regular English Stenotype keyboard.

---

## Chinese (Cantonese)

### SanSan Cantonese Steno (珊々速錄)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/yue-sans.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>sammdot</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Symmetric Toneless Jyutping</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Work in Progress</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://steno.sammdot.ca/explainers">Steno Explainers</a>
    </td>
  </tr>
</table>

SanSan is a Cantonese steno theory under development. Join the Plover Discord for more discussions about Cantonese steno!

---

## Chinese (Mandarin)

### Exun (E讯速录)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/zh-exun.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Symmetric Toneless Pinyin</td>
  </tr>
  <tr>
    <th>Character Set</th>
    <td>Simplified</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
</table>

Exun is a Mandarin steno system used in Mainland China. Not much is known about it other than the fact that it is based on pinyin and uses a structure system for individual character input.

<br>

### Plover TCIM (千鳥詞註)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/zh-tcim.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Quisette</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Symmetric Toneless Zhuyin</td>
  </tr>
  <tr>
    <th>Character Set</th>
    <td>Traditional</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Work in Progress</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/Quisette/plover-TCIM">Plugin Repository</a><br>
        (Not registered in Plugin Manager)
    </td>
  </tr>
</table>

<br>

### Suoheng (索恒速录)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/zh-suoh.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Symmetric Toneless Pinyin</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
</table>

Very little is known about the Suoheng system and there are no plans to implement it in Plover.

<br>

### Yawei (亚伟速录)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/zh-yawe.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Symmetric Toneless Pinyin</td>
  </tr>
  <tr>
    <th>Character Set</th>
    <td>Traditional / Simplified</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Work in Progress</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://zh.wikipedia.org/wiki/%E4%BA%9A%E4%BC%9F%E9%80%9F%E5%BD%95">Wikipedia Page</a>
    </td>
  </tr>
</table>

Yawei is the most commonly used Chinese stenotype system - it is widely used in Mainland China and Taiwan and uses Pinyin without tones as its main way of inputing characters; learners are required to memorize the positions of homophones based on their position in a frequency-based selection menu for fast character entry.

---

## Czech

### Czech Stenograph

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/cs-sten.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
</table>

The Czech layout that comes built-in on some Stenograph machines, including the latest Luminex II.

<br>

### Plover Czech

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/cs-plov.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Ashlynn Anderson (lambdadog)</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Alpha Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/lambdadog/plover_czech">Plugin Repository</a><br>
        (Not registered in Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Not Available</td>
  </tr>
</table>

A Czech steno system designed for Plover.

---

## Danish

### hjejleOrdbog

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/da-hjej.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Lars Rune Præstmark (SeaLiteral)</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>Uses the English Stenotype Plugin</td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>
        Basic: 5,000+ Entries <br>
        Dictionaries can be found <a href="https://github.com/SeaLiteral/hjejleOrdbog">here</a>.
    </td>
  </tr>
</table>

A Danish steno dictionary based on the standard English layout with slight modifications. While the layout is different from the standard English one, this system does not come with a separate system plugin and uses the default English one, so the tape output might not reflect the actual phonetic value of each stroke.

---

## Dutch

### Jade's Dutch System

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/nl-jade.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Jade Geels</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released; not in active development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/Jade-GG/Plover_Dutch">Plugin Repository</a><br>
        (Not registered in Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Basic: 3,400+ Entries</td>
  </tr>
</table>

Dutch steno system that uses a modified version of the English stenotype layout with one extra `G` key on the left.

<br>

### Willem's Dutch System

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/nl-will.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Willem Sonke</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released; in active development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/Willem3141/plover_dutch">Plugin Repository</a><br>
        (Not registered in Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Basic: 7,700+ Entries</td>
  </tr>
</table>

Dutch steno system that uses a modified English stenotype layout. It was made to be as similar as possible to the default English system to minimize confusion between the two; nevertheless, quite a few differences are unavoidable to make the system practical. 

---

## Finnish

### Finnish Especias

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/fi-espe.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Lars Rune Præstmark (SeaLiteral)</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>Uses the English Stenotype Plugin</td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>
        Full orthographic dictionary can be found <a href="https://github.com/SeaLiteral/especias">here</a>.
    </td>
  </tr>
</table>

An orthographic system (spelling-based) for Finnish capable of writing Swedish loadwords. The layout allows writing two "vowels" and two "consonants" per stroke. The available consonants include a few consonant clusters, and the first vowel must be from a list of mostly short vowels and the second vowel is chosen from one of two lists to match the frontness of the first vowel.

---

## French

### Grandjean

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/fr-gran.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Mark Grandjean</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/stenomax/plover_grandjean">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>
        Full Dictionary: 690,000+ Entries <br>
        Dictionaries can be downloaded separately <a href="https://github.com/azizyemloul/plover-france-dict">here</a>.
    </td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        An in-depth explanation of the system can be found <a href="https://github.com/azizyemloul/plover-france-dict">here</a>.
    </td>
  </tr>
</table>

The Grandjean Stenotype was created in 1909; it is also known as the "Continential" layout by some manufacturers and is the preferred phonetic system in France (The orthographic Velotype system is more commonly used for transcribing many TV programs and broadcasts).

<br>

### LaSalle / La TAO

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/fr-lasa.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>Uses the English Stenotype Plugin</td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>
        Basic: 4,200+ Entries <br>
        Dictionaries can be found <a href="https://github.com/morinted/la_tao_dictionary">here</a>.
    </td>
  </tr>
</table>

A French steno system based on the English steno layout; primarily used in Quebec.

---

## German

### Ruben Moor's German Palantype

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/de-gpal.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Work In-Progress, Learning Resources Available</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/rubenmoor/palantype-tools">System Repository</a>
    </td>
  </tr>

  <tr>
    <th>Dictionary</th>
    <td>Generated Dictionary: 100,000+ Entries, with plans to expand to 2 million</td>
  </tr>
  <tr>
  <th>Resources</th>
  <td>
      <a href="https://palantype.com">Tutorial</a>
  </td>
  </tr>
</table>

### Plover German Palantype

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/de-pala.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/percidae/plover_palantype_german">Plugin Repository</a><br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Full Dictionary: 85,000+ Entries</td>
  </tr>
</table>

German steno system based on the Possum Palantype layout with two additional keys.

<br>

### Plover German

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/de-plov.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not in active development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/percidae/plover_german">Plugin Repository</a><br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Not available</td>
  </tr>
</table>

German stenography system for Plover based on the not realtime capable theory of the book "Deutsches System der computerkompatiblen Stenografie". This book can be found in the university library of Dresden and can be read via interlibrary loan. This is also the system that is built into some Stenograph machines.

<br>

### Regenpfeifer

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/de-rege.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Martin Körner (mkrnr)</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Work in Progress</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/mkrnr/plover_regenpfeifer">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Full Dictionary: 219,000+ Entries</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://github.com/mkrnr/regenpfeifer">Dictionary Generator</a>
    </td>
  </tr>
</table>

A German steno system based on a modified English stenotype layout; the `-Z` key is replaced with `-N`.

---

## Greek

### Greek Stenograph

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/el-sten.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
</table>

The Greek layout that built into some Stenograph/Stentura machines. Not much is known about this layout.

---

## Hebrew

### Hebrew Stenograph

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/he-sten.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
</table>

The Hebrew layout that built into some Stenograph/Stentura machines. Not much is known about this layout.

---

## Italian

### Melani

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/it-mela.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Orthographic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/benoit-pierre/plover_melani">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://www.stenolab.it">Stenolab Website</a>
    </td>
  </tr>
</table>

An orthographic theory for Italian writing based on the Tréal machine. This layout is also found on some Stenograph machines.

<br>

### Michela

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/it-mich.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/benoit-pierre/plover_michela">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Full Dictionary: 94,000+ Entries</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        Free theory books are available <a href="https://sillabix.gitbooks.io/dizionario-test/">here</a> and <a href="https://legacy.gitbook.com/book/sillabix/dizionario-ortografico-michela-per-input-sillabic/details">here</a>.
    </td>
  </tr>
</table>

Used by the Italian Senate. A cheap alternative to an official Michela machine is any MIDI keyboard.

---

## Japanese

### 42triangles' Kana System

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/jp-42tr.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>42triangles</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Orthographic 1 Mora + 1 Coda</td>
  </tr>
  <tr>
    <th>Kanji Conversion</th>
    <td>Romaji-only (Relies on User IME)</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
</table>

Simple kana input system designed to work alongside the English layout to input Japanese without switching steno systems.

<br>

### Frag's Japanese System

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/jp-frag.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Frag</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Symmetric 2 Mora + 2 Coda</td>
  </tr>
  <tr>
    <th>Kanji Conversion</th>
    <td>Structure-based</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Work in Progress</td>
  </tr>
</table>

A Japanese steno system created for the Georgi machine; the layout is symmetrical to allow the user to type one kanji on'yomi on each side. This system also addresses the problem of inaccurate kanji conversions in existing systems by introducing a way for users to directly input kanji using a structure-based system where most common kanji can be entered in just one stroke.

This is the updated version of the Japanese layout available on TypeyType.

<br>

### Hachidori (はちどり)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/jp-hach.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Kathy (Kaoffie)</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Symmetric 2 Mora + 2 Coda</td>
  </tr>
  <tr>
    <th>Kanji Conversion</th>
    <td>Hybrid</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Work in Progress</td>
  </tr>
</table>

Japanese steno system created to fix all the downsides of Sokutaipu and introduce an intuitive Kanji input system. The system is symmetrical and each side is capable of inputting a full on'yomi; the layout is designed to keep as many keys from the English layout in the same position as possible whilst also maintaining compatibility with as many hobbyist keyboards as possible.

<br>

### Sokutaipu (ソクタイプ)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/jp-soku.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Semi-Symmetric 2 Mora + 1 Coda</td>
  </tr>
  <tr>
    <th>Kanji Conversion</th>
    <td>Pure Kana (Relies on User IME)</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not in active development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/na4zagin3/plover_japanese_sokutaipu">Plugin Repository</a><br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Full Dictionary: 365,000+ Entries</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="http://hoangmoc123.d.dooo.jp/sokutaipu.html">Kana Table</a>
    </td>
  </tr>
</table>

Also known as the Stentura (ステンチュラ) layout. The two sides are symmetric and are each in charge of a syllable, while the thumb is in charge of connecting the two sides; there are also one-side briefs that can be mirrored on the other side or merged.

<br>

### StenoWord (ステノワード)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/jp-sten.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Orthographic 1-Syllable</td>
  </tr>
  <tr>
    <th>Kanji Conversion</th>
    <td>Pure Kana (Relies on User IME)</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not in active development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/na2hiro/plover-japanese-stenoword">Plugin Repository</a><br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Full Dictionary: 2,600+ Entries</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="http://hoangmoc123.d.dooo.jp/Stenoword.html">Kana Table</a>
    </td>
  </tr>
</table>

The preferred Japanese steno system for NHK live captions; the left hand is for consonants and the right hand is for vowels.

<br>

### Willem's Kana System

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/jp-will.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Willem Sonke</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Orthographic 1 Mora + 1 Coda</td>
  </tr>
  <tr>
    <th>Kanji Conversion</th>
    <td>Romaji-only (Relies on User IME)</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/Willem3141/plover_japanese_kana">Plugin Repository</a><br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
</table>

A way to write Japanese kana in steno. This is not focused on speed; instead it is meant to be easy to learn for English steno users while still being reasonably efficient. It uses the standard English layout.

---

## Korean

### Korean CAS

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/kr-cas.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Orthographic (Initial/Medial/Final) with Briefs</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not in active development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/nsmarkop/plover_korean">Plugin Repository</a> under "Korean Modern C" <br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Partial</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        Documentation and theory basics can be found <a href="https://github.com/nsmarkop/plover_korean/tree/master/plover_korean/system/cas">here</a>.
    </td>
  </tr>
</table>

The Computer Aided Steno-machine, or CAS, was developed by [Korea Steno](http://www.koreasteno.com/) and features one of the two modern stenography systems for Korean in use today.

<br>

### Sorizava (소리자바)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/kr-sori.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Orthographic (Initial/Medial/Final) with Briefs</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not in Development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/nsmarkop/plover_korean">Plugin Repository</a> under "Korean Modern S" <br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Partial</td>
  </tr>
</table>

Sorizava, developed by [a company of the same name](http://www.sorizava.co.kr/), is the second of the modern stenography systems for Korean in use today and the more recent to have been created.

The Sorizava system is not currently under development. There are partial pieces of an implementation in [plover-korean](https://github.com/nsmarkop/plover_korean) but outside of a partial dictionary no theory materials have been obtained to progress further.

---

## Portuguese

### Brazilian Stenotype

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/pt-braz.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/morinted/plover_portuguese">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Basic: 4,000+ Entries (available on the Plover Discord)</td>
  </tr>
</table>

Brazilian Portuguese system used by [Paulo Paniago](http://openstenoblog.blogspot.ca/2015/04/my-experience-in-open-source.html). Also included in some Stenograph machines.

---

## Russian

### Russian Melani

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/ru-mela.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://github.com/openstenoproject/plover/files/247728/Russian.alphabet.and.layout.pdf">Dictionary Sample</a>
    </td>
  </tr>
</table>

Not much is known about this layout; see [this](https://github.com/openstenoproject/plover/issues/492) discussion about Russian steno.

<br>

### Russian Stenograph

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/ru-sten.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
</table>

The Russian layout that built into some Stenograph/Stentura machines. Not much is known about this layout.

<br>

### Trillo (Трилло)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/ru-tril.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Complete</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/morinted/plover_russian_trillo">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Basic: 15,000+ Entries</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://github.com/openstenoproject/plover/files/1533593/Russian.Theory.-.ARA.doc.zip">Textbook</a> (in mixed English/Russian)
    </td>
  </tr>
</table>

A realtime theory for Russian writing based on the Tréal machine.

---

## Spanish

### Spanish Especias

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/es-espe.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Lars Rune Præstmark (SeaLiteral)</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not in active development</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        Basic description available on the <a href="https://github.com/SeaLiteral/especias">GitHub Repository</a>.
    </td>
  </tr>
</table>

A layout that allows writing two "vowels" and two "consonants" per stroke. It uses the same layout as Finnish, except for one of the colon keys being replaced with an s to write plurals. 

<br>

### Spanish Grandjean

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/es-gran.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Relies on existing Grandjean plugin</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/stenomax/plover_grandjean">Grandjean Plugin</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>None publicly available</td>
  </tr>
  <th>Resources</th>
    <td>
      <a href="http://www.estenotipiaasociacion.com">Asociacion Española de Estenotipistas</a>
    </td>
  </tr>
</table>

Spanish system based on French Grandjean layout.

<br>

### Spanish Marino (Método Marino)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/es-mari.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        Uses the English Stenotype Plugin
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>
        None publicly available.
    </td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
      <a href="https://taquigrafica.ucoz.net/publ/edicion_numero_01/2-1-0-14">Overview</a> <br>
      <a href="https://www.facebook.com/stenocap">Facebook Page</a>
    </td>
  </tr>
</table>

Spanish theory used in the Argentine Senate, along with Spanish Grandjean.

<br>

### Spanish MQD

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/es-mela.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/nvdaes/plover_spanish_mqd">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Basic: 11,000+ Entries</td>
  </tr>
</table>

Spanish system based on the Melani Italian layout, used at MQD.

<br>

### Spanish Stenograph

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/es-sten.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
</table>

The Spanish layout that comes built-in on some Stenograph machines, including the latest Luminex II.

<br>

### Spanish System (eo variant)

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/es-eova.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Eliseo Ocampos (roskoff)</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released; in active development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/roskoff/plover_spanish_system_eo_variant">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Full Dictionary: 71,000+ Entries</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        Documentation can be found on the <a href="https://github.com/roskoff/plover_spanish_system_eo_variant">GitHub repository</a>.
    </td>
  </tr>
</table>

Developed for the default Plover layout, proposes a syllabic system trading-off a little of abbreviations for consistent rules.

<br>

### Stanley's Spanish Dictionary

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/es-stan.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Stanley Sakai (Stanographer)</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>Uses the English Stenotype Plugin</td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>
        Basic: 12,000+ Entries <br>
        Available for download <a href="https://github.com/stanographer/steno-dictionaries/blob/master/stanespanol.json">here</a>.
    </td>
  </tr>
</table>

Spanish dictionary designed to be used with the English Stenotype layout.

---

## Swedish

### Swedish Palantype

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/sv-pala.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not in active development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/stenoshrink/plover_swedish_palantype">Plugin Repository</a><br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Dictionary</th>
    <td>Sample: 87,000+ Entries (Autogenerated)</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://github.com/stenoshrink/plover_swedish_palantype/tree/master/Swedish%20theory">Swedish Theory</a>
    </td>
  </tr>
</table>

Swedish steno system based on the English Palantype layout.

---

## Thai

### Thai Steno

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/th-parn.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Parnikkapore</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Work in Progress</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/parnikkapore/plover_thsteno">Plugin Repository</a><br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
</table>

A work-in-progress Thai steno system.

---

## Turkish

### Turkish Stenograph

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/tr-sten.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Phonetic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Not Available for Plover</td>
  </tr>
</table>

The Turkish layout that comes built-in on some Stenograph machines, including the latest Luminex II.

---

## Vietnamese

### Aerick's Vietnamese System

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/vi-aeri.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>Aerick</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Orthographic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released; in active development</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/aerickt/plover_viet">Plugin Repository</a><br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
</table>

Orthographic Vietnamese system designed to input one syllable per stroke.

<br>

### user202729's Vietnamese System

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/vi-user.png?raw=true" width="500">

<table>
  <tr>
    <th>Created by</th>
    <td>user202729</td>
  </tr>
  <tr>
    <th>Type</th>
    <td>Orthographic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/user202729/plover_vi">Plugin Repository</a><br>
        (Download using Plugin Manager)
    </td>
  </tr>
</table>

A Vietnamese steno system based on the English stenotype layout.

---

## Multilingual Systems

### Velotype

<img src="https://github.com/Kaoffie/steno_diags/blob/master/converted/zz-velo.png?raw=true" width="500">

<table>
  <tr>
    <th>Type</th>
    <td>Orthographic</td>
  </tr>
  <tr>
    <th>Development</th>
    <td>Released</td>
  </tr>
  <tr>
    <th>Plugin</th>
    <td>
        <a href="https://github.com/AlexandraAlter/plover_syllabic_chording">Plugin Repository</a><br>
        (Not Registered on Plugin Manager)
    </td>
  </tr>
  <tr>
    <th>Supported Languages</th>
    <td>Dutch, English (can be adapted to more)</td>
  </tr>
  <tr>
    <th>Resources</th>
    <td>
        <a href="https://www.velotype.com/en/homepage-eng/">Official Website</a>
    </td>
  </tr>
</table>

The velotype is an orthographic system designed to support many European languages. It has also been implemented as a separate app in [Qweyboard](https://github.com/kqr/qweyboard) by kqr.
