# Top 100 Words in Plover's Dictionary

What they are, and why they are stroked like that.

## Introduction

Fun fact: The top 100 words in the English language make up about 50% of all written material.

When learning steno theory, you might be confused by the fact that many common words are not written out phonetically. There are many reasons that this is the case, but it boils down to:

- Avoiding [word boundary errors](https://github.com/openstenoproject/plover/wiki/Glossary#word-boundary)
- Ease of stroking

## The List

### 1. the

`-T`

The most common word in the English language is reserved to just one key, right-hand `-T`. The right hand position makes it easy to have a single stroke brief for some of the most common two-word phrases. For example: `SKP-T` for "and the".

### 2. be

`-B`

Right-hand `-B`. The "B" key in Plover just happens to be the "be" key. How convenient! Writing out "be" like `PWE` is the word part "be^". For example: "beware" or "belated". And the phonetic `PWAOE` is "bee"!

### 3. to

`TO`

Written out by spelling, `TO`. This is easy to hit and free of conflicts. 

Warning: `O` for "to" in the default dictionary is a misstroke. It is not free from word boundaries.

### 4. of

`-F`

Right-hand `-F`. This is a simple one key stroke, and it frees up `OF` to be used for "off".

### 5. and

`SKP-`

`SKP-`. This is an easy to hit stroke with only the left hand. This makes it a good candidate for starting phrases, like `SKPU` for "and you".

### 6. a

`AEU` 

`A` is used as a prefix for words like "affix" or "arrive". The tense A sound is used to avoid conflicts. In some theories, these strokes are mixed, and you could swap them safely, if you wanted.

### 7. in

`TPH`

`TPH` is just the left-hand `N`. This combination frees up `EUPB` to be used for the "in^" prefix, like in 
"indoors". Also good for phrases, such as `TPH-T` for "in the".

### 8. that

`THA` 

We drop the ending T to bring this stroke into the left hand for use at the beginning of phrases. Examples: `THAR` for "that are", `THAS` for "that is".

### 9. have

`SR-`

This is the left-hand `V`. The phonetic version of this would be `HA*F` which is much harder to stroke for such a common word, and the left-hand makes right-hand phrase parts feel more natural, like `SR-T` for "have the".

`HAF` and `HA*F` get mapped to "half" and "1/2" in the default dictionary, respectively.

### 10. I

`EU` (`I`)

This is a non-phonetic stroke to give space for "eye". It's easy to hit and fits in some phrases, such as `SKPEU` for "and I". Note that, in some cases, you will use the `AOEU` cluster for I, such as in "I'll" (`AOEUL`) and "I'm" (`AOEUPL`) because the shorter versions are used for other things, in this case "ill" and the word beginning "im^".

### 11. it

`T-` 

This is easy to hit and on the left hand for beginning phrases such as `TWAS` for "it was". Same pattern as for "in" and "if".

### 12. for

`TP-R` (F-R). 

This drops the vowel to save effort for such a common word. If you want to use "for^" the prefix, then use `FAUR`. For example, forgone is `FAUR/TKPWOPB`.

### 13. not

`TPHOT`

### 14. on

`OPB`

### 15. with

`W-`

This is another easy to use single key stroke that can begin phrases like `WOUR` for "with our" and `W-T` for "with the".

### 16. he

`HE` 

This is recommended over the `E`-only version for most cases, but depending on the phrase or word you might need `E` (`SKPE`: and he), `HE` (`HEBGD`: he could), and `HAOE` (`HAO*EL`: he'll)

### 17. as

`AS` (spelling) or `AZ` (phonetic).

### 18. you

`U`

The `U` key is used for "you". Can be used in phrases such as `SKPU` for "and you".

### 19. do

`TKO` (spelling). 

Don't drop the vowel, because `TK-` alone is used for "did".

### 20. at

`AT`

### 21. this

`TH`

"This" is a special case, as it's basically set to `TH` for convenience and to open up the opportunity for several other briefs. For example, `THEU` is used for "think", and `THEUS` follows as "thinks".

Also works in phrases: `TH-FS` for "this was"

### 22. but

`PWUT` or `PWU`. 

Mirabai uses `PWUT` as "but" and that is okay, but you can safely remap `PWUT` to "but the" if you want to use `PWU` as "but" exclusively.

### 23. his

`HEUS` (spelling), `HEUZ` (phonetic)

### 24. by

`PWEU`

This is a non-phonetic mapping to make room for `PWAOEU`: "buy". Add an asterisk to "by" and get the word beginning "bi^", add an asterisk to "buy" and get "bye".

### 25. from

`TPR-` (`FR-`). 

This is similar to "for" (`TP-R`), but instead of dropping just the vowel, we drop the ending -M sound as well. This opens up "from" to phrases, like in `TPRUS` for "from us" and `TPR-T` for "from the" and `TPREUPLT` for "from time to time".

### 26. they

`THE`

Since "the" is stroked with just `-T`, we can place "they" in this stroke. It's important not to use `THAEU` to avoid potential conflict when we get to "they're" and "their".

### 27. we

`WE` (spelling) or `WAOE` (phonetic)

### 28. say

`SAEU` (phonetic).

Advanced: Also present as a right-hand only shortcut as `-BZ`, such as `THEBZ` for "they say". Get the past tense with `-BS` such as `THEBS` for "they said".

### 29. her

`HER`

### 30. she

`SHE` (spelling) or `SHAOE` (phonetic)

### 31. or

`OR`. 

The phonetic version is given instead to "other" (`OER`).

### 32. an

`APB`

### 33. will

`HR-` 

Left-hand L. Useful for phrases, such as `HR-B` for "will be" and `HRU` for "will you".

### 34. my

`PHEU` or `PHAOEU`. 

We break phonetic convention to offer an easier to hit stroke.

### 35. one

`WUPB` (phonetic)

### 36. all

`AUL` (phonetic). 

This vowel is common in the Plover dictionary, such as in `WAUL` (wall) and `PWAUL` (ball).

### 37. would

`WO`. 

Left-hand-only brief is useful for phrases: `WOB` for "would be" and `WOU` for "would you".

### 38. there

`THR-` 

This brief is used to avoid conflict with `THER` for "they're" and `THAEUR` for "their".

### 39. their

`THAEUR` (phonetic). 

The homophone "they're" is stroked with `THER` which is the brief `THE` for "they" with `-R` added on.

### 40. what

`WHA`

Similar to `THA` for "that", `WHAT` is "what the".

### 41. so

`SO` (spelling)

### 42. up

`UP`

Use `AUP` for the word beginning "up^" like `AUP/WARDZ` for "upwards".

### 43. out

`OUT` 

Use `AOUT` for the word beginning "out^" like `AOUT/SPOEBG/*EN` for "outspoken" or `AOUT/RAEUPBLG` for "outrage".

### 44. if

`TP-` 

The bare left F is used for "if". Good as a phrase beginner, such as `TP-T` for "if the". Same pattern as "it" and "in".

### 45. about

`PW-`

The left-hand B is used for "about" as a convenient brief. Some theories do this word differently. One nice benefit of being on the left side is, of course, phrases: `PW-T` for "about the".

### 46. who

`WHO` (spelling). 

We can't use `HAOU` (hue) or `HAO` (hoo).

### 47. get

`TKPWET` or `TKPW-T`

### 48. which

`WEU`. Just a brief.

### 49. go

`TKPWO` (spelling), `TKPWOE` (phonetic), or just `TKPW`.

### 50. me

`PHE` (spelling), `PHAOE` (phonetic). 

As with many of these common words, being less strict on the vowel gives your fingers a potential break.

### 51. when

`WH` (brief) or `WHEPB` (spelling)

### 52. make

`PHAEUBG` (`MAIK`) (phonetic)

### 53. can

The left-hand `K-` only, useful for phrases. `K-B` (can be).

### 54. like

`HRAOEUBG` (phonetic)

### 55. time

`TAOEUPL` (phonetic)

### 56. no

`TPHO` (spelling). 

The phonetic version is saved for "know".

### 57. just

`SKWRUFT` 

Remember that `-F` is sometimes used for S.

### 58. him

`HEUPL`

### 59. know

`TPHOE` (phonetic)

### 60. take

`TAEUBG` (phonetic)

### 61. people

`PAOEPL`

In this case `-PL` is used for the "pl" sound instead of `-M`.

### 62. into

`TPHAO`

`TPH-` is "in", and `AO` is sometimes used for `oo` which sounds liked the vowel in "into". Can't use `TPHAOU` as it is being used by "knew".

### 63. year

`KWRAOER` (phonetic)

### 64. your

`KWROUR` (spelling). 

Don't use `KWRUR` as that's the word ending `^ur` like in `KHROES/KWRUR` (closure).

### 65. good

`TKPWAOD`

### 66. some

`SOPL`

As a word beginning, `S-` and `SPH-` are used: for example, `SPH-PB` for "someone" and `S-G` for "something".

### 67. could

`KO`

Brief like `WO` for "would".

### 68. them

`THEPL`

### 69. see

`SAOE`

### 70. other

`OER`

Shows up as a word part, like in `TPHOER` for "another".

### 71. than

`THAPB` (spelling)

### 72. then

`THEPB` (spelling)

### 73. now

`TPHOU`

### 74. look

`HRAOBG`

### 75. only

`OEPBL`

In Plover's dictionary, `E` is often added to strokes to make them end with an "ee" sound. `OEPBL` can be thought of as "onl/ee". Lots of briefs use this, such as `KRAER` for "contrary" and `TPAEPL` for "family".

### 76. come

`KOPL`

### 77. its

`EUTS`

`T-S` is used for "it's".

### 78. over

`OEFR` 

Emphasizing the tense-O sound to contrast with `OFR` for "offer". To use as a prefix, use `AUFR`, such as `AUFR/TKOPB` for "overdone".

### 79. think

`THEU` (brief), with a whole family: `THEUS` for "thinks", `THEUG` for "thinking".

### 80. also

`HR-S` (brief)

### 81. back

`PWABG`

### 82. after

`AF`

`AFT` is a misstroke entry which you could consider remapping to "aft" or "after the". To use as a prefix, use `AFR`, such as `AFR/TAEUFT` for "aftertaste".

### 83. use

`AOUS` or `AOUZ`

### 84. two

`TWO` (spelling)

### 85. how

`HOU`

### 86. our

`OUR`

### 87. work

`WORBG`

### 88. first

`TPEURS` 

This brief drops the "t" sound for comfort.

### 89. well

`WEL`

### 90. way

`WAEU`

### 91. even

`AOEPB` or `AOEFPB` 

Dropping the -F makes this stroke easier to hit.

### 92. new

`TPHU`

Briefed to avoid conflict with `TPHAOU` for "knew".

### 93. want

`WAPBT`

### 94. because

`PWAUS` or `PWAUZ` (briefs)

### 95. any

`TPHEU` (brief)

### 96. these

`THEZ` (brief) or `THAOES`/`THAOEZ` (phonetic). 

The brief is much easier to hit.

### 97. give

`TKPWEUF`

No need for an asterisk, which is often the case with common words in the Plover dictionary.

### 98. day

`TKAEU` (phonetic)

### 99. most

`PHOFT`, `PHOEFT`, `PHO*ES`, or `PHO*S`. 

Go with the option you like most.

### 100. us

`US`