1. [What is Anki](#what-is-anki)
2. [Setting up Anki](#setting-up-anki)
3. [Making your own deck](#making-your-own-deck)
   1. [Custom Fields](#custom-fields)
   2. [Custom Cards](#custom-cards)
4. [Pre-made Decks](#pre-made-decks)
5. [Useful Anki Add-ons](#useful-anki-add-ons)
6. [Useful Plover Extensions](#useful-plover-extensions)

## What is Anki

Anki is a flashcard program that uses spaced repetition. The basic idea is that
if the card is easy you will see it less often, and if the card is hard you will
see it more often. Anki does not grade you automatically — you have full
control.

It can be useful for learning many things, and for steno people have used it
for memorising briefs and theory rules.

## Setting up Anki

1. Download from here: https://apps.ankiweb.net/
2. [Make your own deck](#making-your-own-deck) or use a [pre-made deck](#pre-made-decks)

## Making your own deck

Making your own deck allows you to have greater control over the cards (e.g.
what briefs)

The most basic way is to use the default deck and add cards to it. "Front" and
"Back" can be whatever you want, though most people put the translation on the
front and the steno stroke on the back.

### Custom Fields

Instead of just "Front" and "Back", you might want more fields like "Pseudo
Steno", "Stroke Diagram", "Notes" etc.

1. [Add a new note type](https://docs.ankiweb.net/editing.html#adding-a-note-type)
   so that it won't interfere with anything else you might use Anki for
2. [Customise the fields](https://docs.ankiweb.net/editing.html#customizing-fields)
   and add whatever you want
3. Add the new fields to the card template (see [custom cards](#custom-cards))

### Custom Cards

The default cards have the "Front" field, and when you answer it shows the
"Back" field, as well as a reverse card. If you want to show more fields, you'll
have to customise your card.

See the [anki docs here](https://docs.ankiweb.net/templates/intro.html),
including the next few pages, for how to do this.

Particular things that are useful for steno are:
- [Text to speech](https://docs.ankiweb.net/templates/fields.html#text-to-speech)

```
{{tts en_US:Front}}
```
Read out the text of the card, which is useful if you want to practice from
dictation. You can also use the [AwesomeTTS](https://ankiweb.net/shared/info/1436550454)
add-on for more voices.

- [Field Styling](https://docs.ankiweb.net/templates/styling.html#field-styling)

in the card:

```
<span class="diagram">{{Strokes}}</span>
```
in the styling:
```css
.diagram {
  font-family: "Stenodisplay Classic"
}
```
There are lots of ways you can style your fields, like making the notes smaller
or colour coding your fields.

The example here uses [Kaoffie's Steno
Font](https://github.com/Kaoffie/steno_font), which uses a font for the steno
strokes to make it into a stroke diagram. You may want to [install the
font](https://docs.ankiweb.net/templates/styling.html#installing-fonts) into
Anki if you can't install fonts on your computer or if you want a portable Anki
deck.

- [Typing input](https://docs.ankiweb.net/templates/fields.html#checking-your-answer)

```
{{type:Back}}
````

Type out the field and when you turn the card over it will color code any
differences. Some people like to check the translation field, some people like
to turn off their dictionaries and check for the strokes.

You might want a
separate field for checking, since you may want prefix/suffix cards like
"{^ing}" but what you type out is actually "ing". Anki does not use this to pick
the rating of the card.

It is also possible to hide the text you are typing by adding the following to
your styling. This might be useful if you want to focus on trusting your muscle
memory.

```css
input[type=text] {
   /* options are disc, circle, square, none */
  -webkit-text-security: disc;
}
```

## Pre-made Decks

- [rchern/steno-anki](https://github.com/rchern/steno-anki)
  - [Learn Plover!](https://sites.google.com/site/learnplover/) 
lessons
  - Top 10K Words
  - Emily's [Symbols](https://github.com/EPLHREU/emily-symbols) and [Modifiers](https://github.com/EPLHREU/emily-modifiers) dictionaries
  - Other community-contributed shared decks
  - Script to generate cards from text file
- [jladdjr/anki-decks](https://github.com/jladdjr/anki-decks)
  - Top 10,000 Project Gutenberg words
  - Basic sounds
- [Steno order and Phonetic strokes](https://ankiweb.net/shared/info/14548087)
  - A small deck with cards on steno order and phonetic strokes
- [percidae/Anki_Plover](https://github.com/percidae/Anki_Plover/releases/)
  - Complete plover dictionary

## Useful Anki Add-ons

[Anki Add-ons](https://docs.ankiweb.net/addons.html) are third party
extensions that add features to anki. To install them, go to Tools -> Add-ons
-> Get Add-ons.

- [Automatic Scoring](https://ankiweb.net/shared/info/1765221856)
  - Automatically selects the difficulty of the card based on how long it took
    to answer it
  - You still have to press "enter" to confirm, so you still have full control
  - You may want to adjust the default time to something different. You can
    [show the answer timer](https://docs.ankiweb.net/deck-options.html#general)
    and look at your [answer button graph](https://docs.ankiweb.net/stats.html#the-graphs)
    to get an idea of what a reasonable time might be.
  - Pairs well with [Advanced Review Bottom Bar](https://ankiweb.net/shared/info/1136455830)
    which makes it easier to see which button has been pre-selected.
- [Anki Connect](https://ankiweb.net/shared/info/2055492159)
  - Needed for some [useful plover extensions](#useful-plover-extensions)
- [Find Missing Words](https://ankiweb.net/shared/info/754868802)
  - Paste in a block of text and this will help you find words you don't have
    cards for
- [Anki Simulator](https://ankiweb.net/shared/info/817108664)
  - Simulates your reviews over time. Useful for choosing settings (e.g. number
    of new cards a day) that won't overwhelm you. (You can see how long you take
    per card that day in the Stats window or below the list of decks, and use this
    to see how many repetitions you want)
- [Persistent Editor](https://ankiweb.net/shared/info/1686259334) (doesn't work with latest Anki version)
  - Keeps the editing window open while reviewing (but hides the current card
    until you've answered it). Useful if you are using a pre-made deck and
    prefer different briefs to the ones that are there.
- [Mini Format Pack](https://ankiweb.net/shared/info/295889520)
  - Gives you more formatting options in the menu. Useful for making lists of
    alternative strokes, or other formatting
- [AwesomeTTS](https://ankiweb.net/shared/info/1436550454)
  - Gives you access to a range of TTS voices and human recorded voices (Forvo).
- [Copy selection field](https://github.com/antistic/anki-copy-selection-field)
  - Lets you copy several selected entries in the Anki browse window, for example to copy into a practice tool like Steno Jig or Typey Type.
    

## Useful Plover Extensions
- [Plover Cards](https://github.com/antistic/plover_cards)
  - See previously typed words/phrases, sorted by various properties (e.g. last
    used, most used), choose your preferred stroke and add them into Anki.
  - Command to quickly bring up the last X words you typed and their
    suggestions in an Anki "Add Card" window
  - Requires [Anki Connect](https://ankiweb.net/shared/info/2055492159)
- [Spectra Lexer](https://github.com/fourshade/spectra_lexer)
  - Analyzes strokes and generates stroke diagrams (click save). Useful for
    having stroke diagrams which explain the stroke.